@@ -1,4 +1,4 @@
-### $Id: FAQ.pm,v 1.6 2001/08/01 01:14:22 danielritz Exp $
+### $Id: FAQ.pm,v 1.4 2000/08/23 08:01:51 edpratomo Exp $
 ### DBD::InterBase Frequently Asked Questions POD
 ### 
 ### This document is Copyright (c)2000 Edwin Pratomo. All rights reserved.
@@ -8,7 +8,7 @@
 ### and copyright notices are retained ( the I<AUTHOR> and I<COPYRIGHT> sections ).
 ### Requests for other distribution rights, including incorporation into 
 ### commercial products, such as books, magazine articles or CD-ROMs should be
-### made to Edwin Pratomo <I<ed.pratomo@computer.org>>.
+### made to Edwin Pratomo <I<edwin@petualangansherina.com>>.
 ###
 ### This module is released under
 ### the 'Artistic' license which you can find in the perl distribution.
@@ -28,11 +28,21 @@ perldoc DBD::InterBase::FAQ
 
 This document serves to answer the most frequently asked questions
 regarding the uses of C<DBD::InterBase>. Current version refers to
-C<DBD::InterBase> version 0.28.4 available on SourceForge.
+C<DBD::InterBase> version 0.21 available in CPAN.
+
+=head1 Installation
+
+=head2 How to run the make test?
+
+After compiling, run the t/create.sql before running 'make test' to create 
+the required test database:
+
+ isql -i t/create.sql
 
 =head1 SQL Operations
 
-=head2 Why do some operations performing positioned update and delete fail when AutoCommit is on? 
+=head2 Why do some operations performing positioned update and delete
+fail when AutoCommit is on? 
 
 The following code snippet fails:
 
@@ -64,25 +74,8 @@ AutoCommit on, you can put the snippet within a block:
      $dbh->commit;
  }
 
-=head2 Nested statement handles break under AutoCommit mode. Any workaround?
-
-The explanation behind this is the same as above. The workaround is also
-much alike:
-
- {
-     $dbh->{AutoCommit} = 0;
-     $sth1 = $dbh->prepare("SELECT * FROM $table");
-     $sth2 = $dbh->prepare("SELECT * FROM $table WHERE id = ?");
-     $sth1->execute;
-
-     while ($row = $sth1->fetchrow_arrayref) {
-        $sth2->execute($row->[0]);
-        $res = $sth2->fetchall_arrayref;
-     }
-     $dbh->commit;
- }
-
-=head2 Why do placeholders fail to bind, generating unknown datatype error message?
+=head2 Why do placeholders fail to bind, generating unknown datatype error
+message?
 
 You can't bind a field name. The following example will fail:
 
@@ -173,7 +166,8 @@ Then, pass it to prepare() method.
 
  $res = $dbh->selectall_arrayref($stmt, $attr);
 
-=head2 Can I set the date/time formatting attributes between prepare and fetch?
+=head2 Can I set the date/time formatting attributes between prepare and
+fetch?
 
 No. C<ib_dateformat>, C<ib_timeformat>, and C<ib_timestampformat> can only
 be set during $sth->prepare. If this is a problem to you, let me know, and
@@ -193,7 +187,8 @@ returns -1, because I don't know how to get the number of affected rows :-}
 
 =head1 Sources for Help
 
-=head2 I can't find the answer for my question here, where should I direct my question?
+=head2 I can't find the answer for my question here, where should I direct
+my question?
 
 For questions regarding InterBase itself, you can join the InterBase mailing
 list at http://www.mers.com/, or if it is not enough, I believe there are
@@ -209,7 +204,8 @@ drop me message or you can post your question to the DBI users mailing list.
 =head2 How can I join the development project?
 
 The project is hosted at sourceforge.net. So send me your sourceforge
-username, and let me know what areas you are interested in. 
+username, and let me know what areas you are interested in. Make sure to read
+the TODO document first.
 
 =head2 Is there a mailing list for DBD::InterBase?
 
@@ -223,7 +219,7 @@ http://www.cpan.org/modules/by-module/DBD/ (stable release only).
 
 =head1 AUTHOR AND COPYRIGHT
 
-Copyright (C) 2000-2001, Edwin Pratomo I<ed.pratomo@computer.org>.
+Copyright (C) 2000, Edwin Pratomo I<ed.pratomo@computer.org>.
 Michael Samanov I<samanov@yahoo.com> contributed some important correction.
 
 =cut
